@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-from hdx.utilities.database import Base
+from hdx.database import Base
 from sqlalchemy import Column, String
 from sqlalchemy import ForeignKey
 
@@ -12,13 +12,13 @@ class DBTestResource(Base):
     format = Column(String, nullable=False)
     dataset_id = Column(String, ForeignKey(DBTestDataset.id), nullable=False)
     url = Column(String, nullable=False)
-    revision_last_updated = Column(String, nullable=False)
+    metadata_modified = Column(String, nullable=False)
     last_modified = Column(String, nullable=False)
 
     def __repr__(self):
-        output = '<Resource(run number=%d, id=%s,\n' % (self.run_number, self.id)
+        output = '<Resource(id=%s, name=%s,\n' % (self.id, self.name)
         output += 'format=%s, dataset id=%s,\n' % (self.format, self.dataset_id)
         output += 'url=%s,\n' % self.url
-        output += 'revision last updated=%s, ' % str(self.revision_last_updated)
+        output += 'metadata modified=%s, ' % str(self.metadata_modified)
         output += 'last_modified=%s)>' % str(self.last_modified)
         return output
